@@ -353,7 +353,12 @@ class BatchProcessor:
         return out
 
     def get_status(self):
-        status = {"bob": "lol", "type": self.db.get_type_counts(), "status": self.db.get_status_counts(), "last": self.db.get_last_jobs(limit=10), "type_status": self.db.get_type_status_counts(), "counts": self.get_job_counts()}
+        # fmt: off
+        status = {
+            "status": self.db.get_status_counts(),
+            "last": self.db.get_last_jobs(limit=20),
+            "counts": self.get_job_counts()}
+        # fmt: on
         return status
 
     def process(self):
