@@ -104,13 +104,10 @@ begin
     if do_book and left_millis <= 0 then
         update throttle_tat t set millis = greatest(tat_millis, now_millis) + (period_millis / limit_count) where t.key = $1;
     end if;
-    -- Tell the caller our status
-    -- return format('now_millis=%L, key=%L, tat=%L, new-tat=%L, separation_millis=%L, do_book=%L, left_millis=%L', now_millis, $1, tat_millis, greatest(tat_millis, now_millis) + (period_millis / limit_count), (period_millis / limit_count), do_book, left_millis);
     return left_millis;
 end
 $$ language plpgsql;
-"""
-        )
+""",[])
 
     # Look at faster batch imports with
     # from psycopg2.extras import execute_values
